@@ -1,15 +1,6 @@
 `buffon.needle` <- function(l = 0.8, d = 1, redraw = TRUE, 
     control = ani.control(interval = 0.05, nmax = 100), ...) {
-    extraArgs = list(...)
-    if (length(extraArgs)) {
-        controlargs = names(formals(ani.control))
-        idx = match(names(extraArgs), controlargs, nomatch = 0)
-        if (any(idx == 0)) 
-            stop("Argument ", names(extraArgs)[idx == 0], "not matched")
-        control[names(extraArgs)] = extraArgs
-        if ("interval" %in% names(extraArgs)) 
-            ani.control(...)
-    }
+    control = checkargs(control, ...) 
     j = 1
     n = 0
     PI = rep(NA, control$nmax)
@@ -72,8 +63,8 @@
             lty = 2:1, col = c("red", "black"), bty = "n", cex = 1.2)
         if (control$saveANI) 
             savePNG(n = j, width = control$width, height = control$height)
+        else Sys.sleep(control$interval)
         j = j + 1
-        Sys.sleep(control$interval)
     }
     invisible(PI)
 } 
